@@ -19,7 +19,7 @@
  * along with "Otags reloaded". If not, see
  * <http://www.gnu.org/licenses/>.
  * 
- * $Id: tags.ml,v 1.16 2012-01-14 21:31:39 tews Exp $
+ * $Id: tags.ml,v 1.17 2012-01-17 08:27:05 tews Exp $
  * 
  * recursive tagging function
  * 
@@ -139,7 +139,7 @@ let tag_class_type_decl write_tag = function
     (match Reparse.stop_char wrong_id_loc with
       | ']' -> (* revised syntax -- type params at end *)
 	let word_number = match vf with
-	  | Ast.BTrue -> 2
+	  | Ast.ViVirtual -> 2
 	  | _ -> 1
 	in
 	write_tag (Reparse.loc_of_nth_word word_number wrong_id_loc) lid
@@ -167,8 +167,8 @@ let rec tag_class_sig_item write_tag csi = match csi with
      *)
     let wrong_id_loc = Ast.loc_of_class_sig_item csi in
     let word_number = match (mf, vf) with
-      | (Ast.BFalse, Ast.BFalse) -> 2
-      | (Ast.BTrue, Ast.BTrue) -> 4
+      | (Ast.MuNil, Ast.ViNil) -> 2
+      | (Ast.MuMutable, Ast.ViVirtual) -> 4
       | _ -> 3
     in
     write_tag (Reparse.loc_of_nth_word word_number wrong_id_loc) id
@@ -180,7 +180,7 @@ let rec tag_class_sig_item write_tag csi = match csi with
      *)
     let wrong_id_loc = Ast.loc_of_class_sig_item csi in
     let word_number = match pf with
-      | Ast.BTrue -> 4
+      | Ast.PrPrivate -> 4
       | _ -> 3
     in
     write_tag (Reparse.loc_of_nth_word word_number wrong_id_loc) id
@@ -192,7 +192,7 @@ let rec tag_class_sig_item write_tag csi = match csi with
      *)
     let wrong_id_loc = Ast.loc_of_class_sig_item csi in
     let word_number = match pf with
-      | Ast.BTrue -> 3
+      | Ast.PrPrivate -> 3
       | _ -> 2
     in
     write_tag (Reparse.loc_of_nth_word word_number wrong_id_loc) id
@@ -328,7 +328,7 @@ let tag_class_decl write_tag = function
     (match Reparse.stop_char wrong_id_loc with
       | ']' -> (* revised syntax -- type params at end *)
 	let word_number = match vf with
-	  | Ast.BTrue -> 2
+	  | Ast.ViVirtual -> 2
 	  | _ -> 1
 	in
 	write_tag (Reparse.loc_of_nth_word word_number wrong_id_loc) lid
@@ -339,18 +339,18 @@ let tag_class_decl write_tag = function
 
 
 let rec tag_class_str_item write_tag csi = match csi with
-  | <:class_str_item< inherit $cexp:ce$ as $lid:_$ >> ->
+  | <:class_str_item< inherit $!:_override$ $cexp:ce$ as $lid:_$ >> ->
     (* The ce can be a class body and is therefore tagged.
      *)
     tag_class_expr write_tag ce
-  | <:class_str_item< value $mutable:mf$ $id$ = $_$ >> ->
+  | <:class_str_item< value $!:_override$ $mutable:mf$ $id$ = $_$ >> ->
     (* missing location information for id See #5147.
      * we need the second or third word, depending on whether 
      * mutable is present.
      *)
     let wrong_id_loc = Ast.loc_of_class_str_item csi in
     let word_number = match mf with
-      | Ast.BTrue -> 3
+      | Ast.MuMutable -> 3
       | _ -> 2
     in
     write_tag (Reparse.loc_of_nth_word word_number wrong_id_loc) id
@@ -361,7 +361,7 @@ let rec tag_class_str_item write_tag csi = match csi with
      *)
     let wrong_id_loc = Ast.loc_of_class_str_item csi in
     let word_number = match mf with
-      | Ast.BTrue -> 4
+      | Ast.MuMutable -> 4
       | _ -> 3
     in
     write_tag (Reparse.loc_of_nth_word word_number wrong_id_loc) id
@@ -372,18 +372,18 @@ let rec tag_class_str_item write_tag csi = match csi with
      *)
     let wrong_id_loc = Ast.loc_of_class_str_item csi in
     let word_number = match pf with
-      | Ast.BTrue -> 4
+      | Ast.PrPrivate -> 4
       | _ -> 3
     in
     write_tag (Reparse.loc_of_nth_word word_number wrong_id_loc) id
-  | <:class_str_item< method $private:pf$ $id$ : $_$ = $_$ >> ->
+  | <:class_str_item< method $!:_override$ $private:pf$ $id$ : $_$ = $_$ >> ->
     (* missing locateion information for id See #5147.
      * we need the second or third word, depending on whether 
      * private is present.
      *)
     let wrong_id_loc = Ast.loc_of_class_str_item csi in
     let word_number = match pf with
-      | Ast.BTrue -> 3
+      | Ast.PrPrivate -> 3
       | _ -> 2
     in
     write_tag (Reparse.loc_of_nth_word word_number wrong_id_loc) id
@@ -566,6 +566,7 @@ and tag_module_expr write_tag = function
   | <:module_expr< $id:_$ >>
     -> ()
 
+  | <:module_expr< (value $exp:_$) >>
   | <:module_expr< $anti:_$ >>
   | <:module_expr< >>
     -> assert false
