@@ -1,6 +1,6 @@
 (* Otags reloaded
  * 
- * Hendrik Tews Copyright (C) 2010
+ * Hendrik Tews Copyright (C) 2010 - 2012
  * 
  * This file is part of "Otags reloaded".
  * 
@@ -19,7 +19,7 @@
  * along with "Otags reloaded". If not, see
  * <http://www.gnu.org/licenses/>.
  * 
- * $Id: types.ml,v 1.7 2010-08-25 13:44:20 tews Exp $
+ * $Id: types.ml,v 1.9 2012-01-14 21:31:40 tews Exp $
  * 
  * global type definitions
  * 
@@ -70,4 +70,4 @@ type tag_functions = {
   finish_tagging : unit -> unit;
 }
 
-exception Camlp4_parsing_error of loc_t * string
+exception Otags_parsing_error of loc_t * string
