@@ -1,6 +1,6 @@
 (* Otags reloaded
  * 
- * Hendrik Tews Copyright (C) 2010
+ * Hendrik Tews Copyright (C) 2010 - 2012
  * 
  * This file is part of "Otags reloaded".
  * 
@@ -19,7 +19,7 @@
  * along with "Otags reloaded". If not, see
  * <http://www.gnu.org/licenses/>.
  * 
- * $Id: types.mli,v 1.7 2010-08-25 13:44:20 tews Exp $
+ * $Id: types.mli,v 1.9 2012-01-14 21:31:40 tews Exp $
  * 
  * global type definitions
  * 
@@ -68,4 +68,14 @@ type tag_functions = {
   finish_tagging : unit -> unit;
 }
 
-exception Camlp4_parsing_error of loc_t * string
+
+(* Exception to wrap an error message and a location to be reported by
+ * otags before continuing on the next input file. Lots of other
+ * exceptions are transformed into Otags_parsing_error's, these are
+ * those exceptions from which otags can recover. Therefore, when this
+ * exceptions is raised, the internal state must be in a relatively
+ * good shape. After this exception is caught the tags for the current
+ * file are written to output, therefore no half tags entry should be
+ * laying around somewhere. 
+ *)
+exception Otags_parsing_error of loc_t * string
